' This script converts the encoding of the input text file to the specified output file.
' Syntax: 
' ConvertCodepage.vbs  	/InputCharset:<input encoding> 
' 						/OutputCharset:<output encoding>
' 						/InputFile:{inputfilepath}
' 						/OutputFile:{outputfilepath}

' Example:
' ConvertCodepage.vbs /InputCharset:ibm850 /OutputCharset:utf-8 /InputFile:{inputfilepath} /OutputFile:{outputfilepath}
' For input and output files simply use the default {inputfilepath} and {outputfilepath} attribute offered by 
' memoQ template editor. 

' Supported encodings:
' 	big5, big5-hkscs, euc-jp, euc-kr, gb18030, gb2312, gbk, ibm-thai, 
'   ibm00858, ibm01140, ibm01141, ibm01142, ibm01143, ibm01144, 
'   ibm01145, ibm01146, ibm01147, ibm01148, ibm01149, ibm037, 
'   ibm1026, ibm273, ibm277, ibm278, ibm280, ibm284, ibm285, ibm297, 
'   ibm420, ibm424, ibm437, ibm500, ibm775, ibm850, ibm852, ibm855, 
'   ibm857, ibm860, ibm861, ibm862, ibm863, ibm864, ibm865, ibm866, 
'   ibm869, ibm870, ibm871, iso-2022-jp, iso-2022-kr, iso-8859-1, 
'   iso-8859-13, iso-8859-15, iso-8859-2, iso-8859-3, iso-8859-4, 
'   iso-8859-5, iso-8859-6, iso-8859-7, iso-8859-8, iso-8859-9, 
'   koi8-r, koi8-u, shift_jis, tis-620, us-ascii, utf-16, utf-16be, 
'   utf-16le, utf-7, utf-8, windows-1250, windows-1251, windows-1252, 
'   windows-1253, windows-1254, windows-1255, windows-1256, 
'   windows-1257, windows-1258, unicode

' Before finalizing the memoQ template, run the test feature, so to make sure the script works properly.

' Inspired by: 
' http://stackoverflow.com/questions/5182102/vb6-vbscript-change-file-encoding-to-ansi


Dim objArguments
Dim strSyntaxtext, strInputCharset, strOutputCharset, strInputFile, strOutputFile 
Dim intReadPosition, intWritePosition
Dim arrCharsets

Const adReadAll = -1
Const adReadLine = -2
Const adSaveCreateOverWrite = 2
Const adSaveCreateNotExist = 1
Const adTypeBinary = 1
Const adTypeText = 2
Const adWriteChar = 0
Const adWriteLine = 1

arrCharsets = Split("big5,big5-hkscs,euc-jp,euc-kr,gb18030,gb2312,gbk,ibm-thai," &_
                    "ibm00858,ibm01140,ibm01141,ibm01142,ibm01143,ibm01144," &_
                    "ibm01145,ibm01146,ibm01147,ibm01148,ibm01149,ibm037," &_
                    "ibm1026,ibm273,ibm277,ibm278,ibm280,ibm284,ibm285,ibm297," &_
                    "ibm420,ibm424,ibm437,ibm500,ibm775,ibm850,ibm852,ibm855," &_
                    "ibm857,ibm860,ibm861,ibm862,ibm863,ibm864,ibm865,ibm866," &_
                    "ibm869,ibm870,ibm871,iso-2022-jp,iso-2022-kr,iso-8859-1," &_
                    "iso-8859-13,iso-8859-15,iso-8859-2,iso-8859-3,iso-8859-4," &_
                    "iso-8859-5,iso-8859-6,iso-8859-7,iso-8859-8,iso-8859-9," &_
                    "koi8-r,koi8-u,shift_jis,tis-620,us-ascii,utf-16,utf-16be," &_
                    "utf-16le,utf-7,utf-8,windows-1250,windows-1251,windows-1252," &_
                    "windows-1253,windows-1254,windows-1255,windows-1256," &_
                    "windows-1257,windows-1258,unicode", ",")

Set objFileSystem = CreateObject("Scripting.FileSystemObject")


' Querying and verifying the arguments of the command

Set objArgumentsNamed = WScript.Arguments.Named
If objArgumentsNamed.Count = 0  Then 
   WScript.Quit(99)
End If

For Each objArgumentNamed in objArgumentsNamed
   Select Case Lcase(objArgumentNamed)
      Case "inputcharset"
         strInputCharset = LCase(objArgumentsNamed(objArgumentNamed))
         If Not IsCharset(strInputCharset) Then 
            WScript.Quit(1)
         End If
      Case "outputcharset"
         strOutputCharset = LCase(objArgumentsNamed(objArgumentNamed))
         If Not IsCharset(strOutputCharset) Then 
            WScript.Quit(2)
         End If
      Case "inputfile"
         strInputFile = LCase(objArgumentsNamed(objArgumentNamed))
         If Not objFileSystem.FileExists(strInputFile) Then  
            WScript.Quit(3)
         End If
      Case "outputfile"
         strOutputFile = LCase(objArgumentsNamed(objArgumentNamed))
         If objFileSystem.FileExists(strOutputFile) Then  
            WScript.Quit(4)
         End If
      Case Else
         WScript.Quit(5)
   End Select 
Next



If Len(strInputCharset) > 0 And Len(strOutputCharset) > 0 And Len(strInputFile) > 0 And Len(strOutputFile) > 0 Then 

' Executing the conversion

   Set objInputStream = CreateObject("ADODB.Stream")
   Set objOutputStream = CreateObject("ADODB.Stream")

   With objInputStream
      .Open
      .Type = adTypeBinary
      .LoadFromFile strInputFile
      .Type = adTypeText
      .Charset = strInputCharset
      intWritePosition = 0
      objOutputStream.Open
      objOutputStream.Charset = strOutputCharset
      Do While .EOS <> True
         strText = .ReadText(adReadLine)
         objOutputStream.WriteText strText, adWriteLine
      Loop
      .Close
   End With
   objOutputStream.SaveToFile strOutputFile , adSaveCreateNotExist
   objOutputStream.Close
Else

' If parameters missing, skip execution
	WScript.Quit(98)
End If

' Clearing variables

Set strInputFile = Nothing
Set strOutputFile = Nothing
Set objArguments = Nothing
Set strSyntaxtext = Nothing
Set strInputCharset = Nothing
Set strOutputCharset = Nothing
Set intReadPosition = Nothing
Set intWritePosition = Nothing
Set arrCharsets = Nothing



' Function to determine if the specified codepage attribute values are valid

Function IsCharset(strMyCharset)
IsCharset = False
For Each strCharset in arrCharsets
   If strCharset = strMyCharset Then 
      IsCharset = True
      Exit For
   End If
Next
End Function 

